[SCM] Samba Shared Repository - branch master updated

Andrew Tridgell tridge at samba.org
Mon Nov 8 17:06:02 MST 2010


The branch, master has been updated
       via  d1d585e s4-test: make sure the selftest prefix exists
       via  9c7228d s4-drs: reduce verbosity of dreplsrv_out_connection_attach
       via  eee2742 heimdal: fixed a shadowed variable warning for error_message
      from  0aeb08e s4-attid: Uppercase ATTID type constants

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit d1d585e208bf60729e0c064be7f419ead02875b8
Author: Andrew Tridgell <tridge at samba.org>
Date:   Tue Nov 9 10:22:48 2010 +1100

    s4-test: make sure the selftest prefix exists
    
    Autobuild-User: Andrew Tridgell <tridge at samba.org>
    Autobuild-Date: Tue Nov  9 00:05:22 UTC 2010 on sn-devel-104

commit 9c7228d6aa5e63d4d14cce84349edef04f61bf68
Author: Andrew Tridgell <tridge at samba.org>
Date:   Tue Nov 9 10:05:49 2010 +1100

    s4-drs: reduce verbosity of dreplsrv_out_connection_attach

commit eee27427d23608522f2b20e7bf348a0dd790e643
Author: Andrew Tridgell <tridge at samba.org>
Date:   Tue Nov 9 08:51:20 2010 +1100

    heimdal: fixed a shadowed variable warning for error_message
    
    Pair-Programmed-With: Andrew Bartlett <abartlet at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 source4/dsdb/repl/drepl_partitions.c   |    4 +-
 source4/heimdal/lib/krb5/config_file.c |   46 ++++++++++++++++----------------
 source4/selftest/wscript               |    3 ++
 3 files changed, 28 insertions(+), 25 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/dsdb/repl/drepl_partitions.c b/source4/dsdb/repl/drepl_partitions.c
index d4511f6..ee9210d 100644
--- a/source4/dsdb/repl/drepl_partitions.c
+++ b/source4/dsdb/repl/drepl_partitions.c
@@ -208,9 +208,9 @@ WERROR dreplsrv_out_connection_attach(struct dreplsrv_service *s,
 
 		DLIST_ADD_END(s->connections, conn, struct dreplsrv_out_connection *);
 
-		DEBUG(2,("dreplsrv_out_connection_attach(%s): create\n", conn->binding->host));
+		DEBUG(4,("dreplsrv_out_connection_attach(%s): create\n", conn->binding->host));
 	} else {
-		DEBUG(2,("dreplsrv_out_connection_attach(%s): attach\n", conn->binding->host));
+		DEBUG(4,("dreplsrv_out_connection_attach(%s): attach\n", conn->binding->host));
 	}
 
 	*_conn = conn;
diff --git a/source4/selftest/wscript b/source4/selftest/wscript
index 19f7a0b..a5fafa3 100644
--- a/source4/selftest/wscript
+++ b/source4/selftest/wscript
@@ -154,6 +154,9 @@ def cmd_testonly(opt):
     if os.path.exists(st_done):
         os.unlink(st_done)
 
+    if not os.path.isdir(env.SELFTEST_PREFIX):
+        os.makedirs(env.SELFTEST_PREFIX, int('755', 8))
+
     # We use the full path rather than relative path because it cause problems on some plateforms (ie. solaris 8).
     cmd = '(${PERL} %s/../selftest/selftest.pl --prefix=${SELFTEST_PREFIX} --builddir=. --srcdir=. --exclude=./selftest/skip --testlist="${PYTHON} ./selftest/tests.py|" ${OPTIONS} --socket-wrapper ${TESTS} && touch ${SELFTEST_PREFIX}/st_done) | ${FILTER_OPTIONS} | tee ${SELFTEST_PREFIX}/subunit' % (os.getcwd())
     if os.environ.get('RUN_FROM_BUILD_FARM') is None and not Options.options.FILTERED_SUBUNIT:


diff --git a/source4/heimdal/lib/krb5/config_file.c b/source4/heimdal/lib/krb5/config_file.c
index 22d0b90..5840b8d 100644
--- a/source4/heimdal/lib/krb5/config_file.c
+++ b/source4/heimdal/lib/krb5/config_file.c
@@ -75,14 +75,14 @@ config_fgets(char *str, size_t len, struct fileptr *ptr)
 
 static krb5_error_code parse_section(char *p, krb5_config_section **s,
 				     krb5_config_section **res,
-				     const char **error_message);
+				     const char **err_message);
 static krb5_error_code parse_binding(struct fileptr *f, unsigned *lineno, char *p,
 				     krb5_config_binding **b,
 				     krb5_config_binding **parent,
-				     const char **error_message);
+				     const char **err_message);
 static krb5_error_code parse_list(struct fileptr *f, unsigned *lineno,
 				  krb5_config_binding **parent,
-				  const char **error_message);
+				  const char **err_message);
 
 static krb5_config_section *
 get_entry(krb5_config_section **parent, const char *name, int type)
@@ -119,25 +119,25 @@ get_entry(krb5_config_section **parent, const char *name, int type)
  *
  * starting at the line in `p', storing the resulting structure in
  * `s' and hooking it into `parent'.
  * Store the error message in `error_message'.
  */
 
 static krb5_error_code
 parse_section(char *p, krb5_config_section **s, krb5_config_section **parent,
-	      const char **error_message)
+	      const char **err_message)
 {
     char *p1;
     krb5_config_section *tmp;
 
     p1 = strchr (p + 1, ']');
     if (p1 == NULL) {
-	*error_message = "missing ]";
+	*err_message = "missing ]";
 	return KRB5_CONFIG_BADFORMAT;
     }
     *p1 = '\0';
     tmp = get_entry(parent, p + 1, krb5_config_list);
     if(tmp == NULL) {
-	*error_message = "out of memory";
+	*err_message = "out of memory";
 	return KRB5_CONFIG_BADFORMAT;
     }
     *s = tmp;
@@ -147,12 +147,12 @@ parse_section(char *p, krb5_config_section **s, krb5_config_section **parent,
 /*
  * Parse a brace-enclosed list from `f', hooking in the structure at
  * `parent'.
  * Store the error message in `error_message'.
  */
 
 static krb5_error_code
 parse_list(struct fileptr *f, unsigned *lineno, krb5_config_binding **parent,
-	   const char **error_message)
+	   const char **err_message)
 {
     char buf[BUFSIZ];
     krb5_error_code ret;
@@ -175,12 +175,12 @@ parse_list(struct fileptr *f, unsigned *lineno, krb5_config_binding **parent,
 	    return 0;
 	if (*p == '\0')
 	    continue;
-	ret = parse_binding (f, lineno, p, &b, parent, error_message);
+	ret = parse_binding (f, lineno, p, &b, parent, err_message);
 	if (ret)
 	    return ret;
     }
     *lineno = beg_lineno;
-    *error_message = "unclosed {";
+    *err_message = "unclosed {";
     return KRB5_CONFIG_BADFORMAT;
 }
 
@@ -191,7 +191,7 @@ parse_list(struct fileptr *f, unsigned *lineno, krb5_config_binding **parent,
 static krb5_error_code
 parse_binding(struct fileptr *f, unsigned *lineno, char *p,
 	      krb5_config_binding **b, krb5_config_binding **parent,
-	      const char **error_message)
+	      const char **err_message)
 {
     krb5_config_binding *tmp;
     char *p1, *p2;
@@ -201,14 +201,14 @@ parse_binding(struct fileptr *f, unsigned *lineno, char *p,
     while (*p && *p != '=' && !isspace((unsigned char)*p))
 	++p;
     if (*p == '\0') {
-	*error_message = "missing =";
+	*err_message = "missing =";
 	return KRB5_CONFIG_BADFORMAT;
     }
     p2 = p;
     while (isspace((unsigned char)*p))
 	++p;
     if (*p != '=') {
-	*error_message = "missing =";
+	*err_message = "missing =";
 	return KRB5_CONFIG_BADFORMAT;
     }
     ++p;
@@ -218,14 +218,14 @@ parse_binding(struct fileptr *f, unsigned *lineno, char *p,
     if (*p == '{') {
 	tmp = get_entry(parent, p1, krb5_config_list);
 	if (tmp == NULL) {
-	    *error_message = "out of memory";
+	    *err_message = "out of memory";
 	    return KRB5_CONFIG_BADFORMAT;
 	}
-	ret = parse_list (f, lineno, &tmp->u.list, error_message);
+	ret = parse_list (f, lineno, &tmp->u.list, err_message);
     } else {
 	tmp = get_entry(parent, p1, krb5_config_string);
 	if (tmp == NULL) {
-	    *error_message = "out of memory";
+	    *err_message = "out of memory";
 	    return KRB5_CONFIG_BADFORMAT;
 	}
 	p1 = p;
@@ -341,14 +341,14 @@ parse_plist_config(krb5_context context, const char *path, krb5_config_section *
 
 /*
  * Parse the config file `fname', generating the structures into `res'
  * returning error messages in `error_message'
  */
 
 static krb5_error_code
 krb5_config_parse_debug (struct fileptr *f,
 			 krb5_config_section **res,
 			 unsigned *lineno,
-			 const char **error_message)
+			 const char **err_message)
 {
     krb5_config_section *s = NULL;
     krb5_config_binding *b = NULL;
@@ -366,19 +366,19 @@ krb5_config_parse_debug (struct fileptr *f,
 	if (*p == '#' || *p == ';')
 	    continue;
 	if (*p == '[') {
-	    ret = parse_section(p, &s, res, error_message);
+	    ret = parse_section(p, &s, res, err_message);
 	    if (ret)
 		return ret;
 	    b = NULL;
 	} else if (*p == '}') {
-	    *error_message = "unmatched }";
+	    *err_message = "unmatched }";
 	    return EINVAL;	/* XXX */
 	} else if(*p != '\0') {
 	    if (s == NULL) {
-		*error_message = "binding before section";
+		*err_message = "binding before section";
 		return EINVAL;
 	    }
-	    ret = parse_binding(f, lineno, p, &b, &s->u.list, error_message);
+	    ret = parse_binding(f, lineno, p, &b, &s->u.list, err_message);
 	    if (ret)
 		return ret;
 	}
@@ -119,25 +119,25 @@ get_entry(krb5_config_section **parent, const char *name, int type)
  * starting at the line in `p', storing the resulting structure in
  * `s' and hooking it into `parent'.
- * Store the error message in `error_message'.
+ * Store the error message in `err_message'.
  */
 
@@ -147,12 +147,12 @@ parse_section(char *p, krb5_config_section **s, krb5_config_section **parent,
  * Parse a brace-enclosed list from `f', hooking in the structure at
  * `parent'.
- * Store the error message in `error_message'.
+ * Store the error message in `err_message'.
  */
 
@@ -341,14 +341,14 @@ parse_plist_config(krb5_context context, const char *path, krb5_config_section *
 /*
  * Parse the config file `fname', generating the structures into `res'
- * returning error messages in `error_message'
+ * returning error messages in `err_message'
  */
 
-- 
Samba Shared Repository


More information about the samba-cvs mailing list